package com.projetloki.genesis;

/**
 * Enum for the visibility property.
 * Specifies whether an element is visible — that is, whether the box(es) that
 * are generated by an element are rendered.
 *
 * @see <a target="_blank" href="https://developer.mozilla.org/en-US/docs/CSS/visibility">MDN</a>
 *
 * @author Clément Roux
 */
public enum VisibilityValue {
  /** The box is visible. */
  VISIBLE("visible"),
  /**
   * The box is invisible (fully transparent, nothing is drawn), but still
   * affects layout.  Descendants of the element will be visible if they have
   * visibility:visible (this doesn't work in IE up to version 7).
   */
  HIDDEN("hidden"),
  /**
   * For table rows, columns, column groups, and row groups the row(s) or
   * column(s) are hidden and the space they would have occupied is.
   * However, the size of other rows and columns is still calculated as though
   * the cells in the collapsed row(s) or column(s) are present. This was
   * designed for fast removal of a row/column from a table without having to
   * recalculate widths and heights for every portion of the table.
   */
  COLLAPSE("collapse"),
  INHERIT("inherit");
  final String css;

  private VisibilityValue(String css) {
    this.css = css;
  }

  @Override public String toString() {
    return css;
  }
}
